"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    Absolute: function() {
        return Absolute;
    },
    Fixed: function() {
        return Fixed;
    },
    Relative: function() {
        return Relative;
    },
    Static: function() {
        return Static;
    },
    Sticky: function() {
        return Sticky;
    }
});
var _interop_require_default = require("@swc/helpers/_/_interop_require_default");
var _object_spread = require("@swc/helpers/_/_object_spread");
var _object_without_properties = require("@swc/helpers/_/_object_without_properties");
var _clsx = /*#__PURE__*/ _interop_require_default._(require("clsx"));
var _react = /*#__PURE__*/ _interop_require_default._(require("react"));
var _utils = require("../utils");
var _Box = require("../Box");
var Direction = /*#__PURE__*/ function(Direction) {
    Direction["INSET"] = "inset";
    Direction["Y"] = "inset-y";
    Direction["X"] = "inset-x";
    Direction["LEFT"] = "left";
    Direction["RIGHT"] = "right";
    Direction["TOP"] = "top";
    Direction["BOTTOM"] = "bottom";
    return Direction;
}(Direction || {});
function PositionBase(props) {
    var className = props.className, position = props.position, zIndex = props.zIndex, inset = props.inset, x = props.x, y = props.y, top = props.top, bottom = props.bottom, left = props.left, right = props.right, boxProps = _object_without_properties._(props, [
        "className",
        "position",
        "zIndex",
        "inset",
        "x",
        "y",
        "top",
        "bottom",
        "left",
        "right"
    ]);
    // TODO: Support responsive
    var positionDirectionClassNames = resolveClassName({
        inset: inset,
        x: x,
        y: y,
        top: top,
        bottom: bottom,
        left: left,
        right: right
    });
    return /*#__PURE__*/ _react.default.createElement(_Box.Box, _object_spread._({
        className: (0, _clsx.default)((0, _utils.responsive)(_utils.resolveValue, position), positionDirectionClassNames, (0, _utils.responsive)(_utils.resolveValue, zIndex), className)
    }, boxProps));
}
function Static(props) {
    return /*#__PURE__*/ _react.default.createElement(PositionBase, _object_spread._({
        position: "static"
    }, props));
}
function Relative(props) {
    return /*#__PURE__*/ _react.default.createElement(PositionBase, _object_spread._({
        position: "relative"
    }, props));
}
function Absolute(props) {
    return /*#__PURE__*/ _react.default.createElement(PositionBase, _object_spread._({
        position: "absolute"
    }, props));
}
function Fixed(props) {
    return /*#__PURE__*/ _react.default.createElement(PositionBase, _object_spread._({
        position: "fixed"
    }, props));
}
function Sticky(props) {
    return /*#__PURE__*/ _react.default.createElement(PositionBase, _object_spread._({
        position: "sticky"
    }, props));
}
function getClassName(dir, value) {
    if (value == null) {
        return '';
    }
    var isNegative = typeof value === 'number' && value < 0 || typeof value === 'string' && value[0] === '-';
    var normalizedValue = typeof value === 'number' ? Math.abs(value) : value.substring(1);
    var className = "".concat(dir, "-").concat(normalizedValue);
    return isNegative ? "-".concat(className) : className;
}
function resolveClassName(direction) {
    if ('inset' in direction) {
        return getClassName("inset", direction.inset);
    }
    // Always resolve to the most specific
    var top = 'y' in direction ? direction.y : direction.top;
    var bottom = 'y' in direction ? direction.y : direction.bottom;
    var left = 'x' in direction ? direction.x : direction.left;
    var right = 'x' in direction ? direction.x : direction.right;
    if (top === bottom && left === right && top === left) {
        return getClassName("inset", top);
    }
    var classNames = [];
    if (top === bottom) {
        classNames.push(getClassName("inset-y", top));
    } else {
        classNames.push(getClassName("top", top), getClassName("bottom", bottom));
    }
    if (left === right) {
        classNames.push(getClassName("inset-x", left));
    } else {
        classNames.push(getClassName("left", left), getClassName("right", right));
    }
    return (0, _clsx.default)(classNames);
}

//# sourceMappingURL=Position.js.map